//Define Options and Pins
//================================================================
#define FOSC 10000000 //1MHz external osc

#define BAUD 115200
#define MYUBRR 10	//115200 BAUD
#define divided_clock	156250
#define gyro_scale		341			//13.3 mV/(degree/sec) and 3FF/4 counts/Volt.  13.33*0.25575=3.41 **3ff is ADC accuracy

#define sbi(var, mask)   ((var) |= (uint8_t)(1 << mask))
#define cbi(var, mask)   ((var) &= (uint8_t)~(1 << mask))

//PortC
#define AZ		0
#define AY		1
#define AX		2
#define VREF	3
#define MTEMP	4
#define MST		5

//PortD
#define STATUS_LED 3
#define GS1	6
#define SLEEP	7

//Ranges
#define RANGE_15G       '1'
#define RANGE_6G        '2'

//Display Modes
#define GRAVITY '1'
#define RAW     '2'
#define BINARY  '3'
#define DEGREE	'4'

//Gyroscope Constants
#define RATE_CHANNEL	0x04
#define	TEMP_CHANNEL	0X0C
#define ADC_MASK		0X3FF

//Tilt Modes
#define ACTIVE 1
#define INACTIVE 0
#define POSITIVE 1
#define NEGATIVE 0

#define LOW_BYTE	0
#define HIGH_BYTE	1
//================================================================

//EEPROM Memory Structuree
//============================
#define SizeOfConfig	10
#define SizeOfCal		12
#define	SizeOfSensor	4
#define SizeOfGyro		3

#define	ConfigStartAdd	0
#define	CalStartAdd		ConfigStartAdd + SizeOfConfig
#define	TriAxStartAdd	CalStartAdd + SizeOfCal
#define	GyroStartAdd	TriAxStartAdd + SizeOfSensor
#define RunCountAdd		GyroStartAdd + SizeOfGyro

//Struct Variable Offsets (for storage in EEPROM)
//============================
//Triax Sensor Offsets
#define	x_status_addr	0
#define y_status_addr	1
#define z_status_addr	2
#define b_status_addr	3
//Gyroscope Offsets
#define status_addr		0
#define	zero_addr		1
//Config Offsets
#define display_mode_addr	0
#define range_mode_addr		1
#define delay_amount_addr	2
#define baud_rate_addr		4
#define threshold_addr		5
#define gthreshold_addr		6
#define rthreshold_addr		7
#define bthreshold_addr		8
//Calibration Offsets
#define x_midpoint_addr		0
#define y_midpoint_addr		2
#define z_midpoint_addr		4
#define x_1g_addr			6
#define y_1g_addr			8
#define z_1g_addr			10

//Configuration Variables
//==============================
//Define Global Variables
//================================================================
typedef struct{
	uint8_t display_mode;
	uint8_t range_mode;
	uint16_t delay_amount;
	uint8_t baud_rate;
	uint8_t threshold;
	uint8_t gthreshold;
	uint8_t rthreshold;
	uint16_t bthreshold;
} ConfigStruct;

typedef struct{
	uint16_t x_val;
	uint16_t y_val;
	uint16_t z_val;
	uint16_t b_val;
	uint8_t x_status;
	uint8_t y_status;
	uint8_t z_status;
	uint8_t b_status;
} SensorStruct;

typedef struct{
	uint16_t X_Midpoint;
	uint16_t Y_Midpoint;
	uint16_t Z_Midpoint;
	uint16_t X_1g;
	uint16_t Y_1g;
	uint16_t Z_1g;
} CalStruct;

typedef struct{
	uint16_t rate;
	uint16_t temperature;
	uint8_t status;
	uint16_t zero;
} GyroStruct;

//================================================================

